==> sqlitestudio-3.0.7.tar.gz: Plugins/CsvImport/CsvImport_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk_SK">
<context>
    <name>CsvImport</name>
    <message>
        <location filename="csvimport.cpp" line="30"/>
        <source>Cannot read file %1</source>
        <translation>Nemôžem čítať súbor %1</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="62"/>
        <source>Could not find any data in the file %1.</source>
        <translation>Nemôžem nájsť dáta v súbore %1.</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="167"/>
        <source>Enter the custom separator character.</source>
        <translation>Zadajte vlastný oddeľovač.</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="181"/>
        <source>Enter the value that will be interpreted as a NULL.</source>
        <translation>Zadajte hodnotu, ktorá bude interpretovaná ako NULL.</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="194"/>
        <source>CSV files (*.csv);;Text files (*.txt);;All files (*)</source>
        <translation>CSV súbory (*.csv);;Textové súbory (*.txt);;Všetky súbory (*)</translation>
    </message>
</context>
<context>
    <name>csvImportOptions</name>
    <message>
        <location filename="CsvImportOptions.ui" line="24"/>
        <source>, (comma)</source>
        <translation>, (čiarka)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="29"/>
        <source>; (semicolon)</source>
        <translation>; (bodkočiarka)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="34"/>
        <source>\t (tab)</source>
        <translation>\t (tabulátor)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="39"/>
        <source>  (whitespace)</source>
        <translation>  (medzera)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="44"/>
        <source>Custom:</source>
        <translation>Iný:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="52"/>
        <source>&lt;p&gt;Enable this if the first data line in your CSV file represents column names. You don&apos;t want column names to be imported into the table as a regular data.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Zaškrtnite túto voľbu ak prvý riadok v CSV súbore obsahuje názvy stĺpcov a nechcete aby boli naimportované do tabuľky&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="55"/>
        <source>First line represents CSV column names</source>
        <translation>Názvy stĺpcov v prvom riadku</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="65"/>
        <source>Field separator:</source>
        <translation>Oddeľovač:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="85"/>
        <source>NULL values:</source>
        <translation>NULL hodnoty:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="95"/>
        <source>If your CSV data contains null values, define how are they represented in the CSV.</source>
        <translation>Ak váš CSV súbor obsahuje null hodnoty, zadajte ako sú reprezentované v CSV.</translation>
    </message>
</context>
</TS>

==> sqlitestudio_3.1.0.orig.tar.gz: Plugins/CsvImport/CsvImport_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sk_SK">
<context>
    <name>CsvImport</name>
    <message>
        <location filename="csvimport.cpp" line="30"/>
        <source>Cannot read file %1</source>
        <translation>Nemôžem čítať súbor %1</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="62"/>
        <source>Could not find any data in the file %1.</source>
        <translation>Nemôžem nájsť dáta v súbore %1.</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="163"/>
        <source>Enter the custom separator character.</source>
        <translation>Zadajte vlastný oddeľovač.</translation>
    </message>
    <message>
        <source>Enter the value that will be interpreted as a NULL.</source>
        <translation type="obsolete">Zadajte hodnotu, ktorá bude interpretovaná ako NULL.</translation>
    </message>
    <message>
        <location filename="csvimport.cpp" line="186"/>
        <source>CSV files (*.csv);;Text files (*.txt);;All files (*)</source>
        <translation>CSV súbory (*.csv);;Textové súbory (*.txt);;Všetky súbory (*)</translation>
    </message>
</context>
<context>
    <name>csvImportOptions</name>
    <message>
        <location filename="CsvImportOptions.ui" line="24"/>
        <source>, (comma)</source>
        <translation>, (čiarka)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="29"/>
        <source>; (semicolon)</source>
        <translation>; (bodkočiarka)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="34"/>
        <source>\t (tab)</source>
        <translation>\t (tabulátor)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="39"/>
        <source>  (whitespace)</source>
        <translation>  (medzera)</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="44"/>
        <source>Custom:</source>
        <translation>Iný:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="52"/>
        <source>&lt;p&gt;Enable this if the first data line in your CSV file represents column names. You don&apos;t want column names to be imported into the table as a regular data.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Zaškrtnite túto voľbu ak prvý riadok v CSV súbore obsahuje názvy stĺpcov a nechcete aby boli naimportované do tabuľky&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="55"/>
        <source>First line represents CSV column names</source>
        <translation>Názvy stĺpcov v prvom riadku</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="65"/>
        <source>Field separator:</source>
        <translation>Oddeľovač:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="85"/>
        <source>If enabled, then text value provided on the right will be interpreted as NULL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="88"/>
        <source>NULL values:</source>
        <translation>NULL hodnoty:</translation>
    </message>
    <message>
        <location filename="CsvImportOptions.ui" line="98"/>
        <source>If your CSV data contains null values, define how are they represented in the CSV.</source>
        <translation>Ak váš CSV súbor obsahuje null hodnoty, zadajte ako sú reprezentované v CSV.</translation>
    </message>
</context>
</TS>
